@@ -35,19 +35,20 @@ using namespace Gravatar;
 
 Q_GLOBAL_STATIC(GravatarCache, s_gravatarCache)
 
-class Gravatar::GravatarCachePrivate
+class Q_DECL_HIDDEN Gravatar::GravatarCachePrivate
 {
 public:
-    template <typename T>
+    template<typename T>
     inline void insertMissingHash(std::vector<T> &vec, const T &hash)
     {
         auto it = std::lower_bound(vec.begin(), vec.end(), hash);
-        if (it != vec.end() && *it == hash)
+        if (it != vec.end() && *it == hash) {
             return; // already present (shouldn't happen)
+        }
         vec.insert(it, hash);
     }
 
-    template <typename T>
+    template<typename T>
     inline void saveVector(const std::vector<T> &vec, const QString &fileName)
     {
         QSaveFile f(mGravatarPath + fileName);
@@ -57,26 +58,27 @@ public:
         }
 
         f.resize(vec.size() * sizeof(T));
-        f.write(reinterpret_cast<const char*>(vec.data()), vec.size() * sizeof(T));
+        f.write(reinterpret_cast<const char *>(vec.data()), vec.size() * sizeof(T));
         f.commit();
     }
 
-    template <typename T>
+    template<typename T>
     inline void loadVector(std::vector<T> &vec, const QString &fileName)
     {
-        if (!vec.empty()) // already loaded
+        if (!vec.empty()) { // already loaded
             return;
+        }
 
         QFile f(mGravatarPath + fileName);
-        if (!f.open(QFile::ReadOnly))
+        if (!f.open(QFile::ReadOnly)) {
             return; // does not exist yet
-
+        }
         if (f.size() % sizeof(T) != 0) {
             qCWarning(GRAVATAR_LOG) << "Missing hash cache is corrupt:" << f.fileName();
             return;
         }
         vec.resize(f.size() / sizeof(T));
-        f.read(reinterpret_cast<char*>(vec.data()), f.size());
+        f.read(reinterpret_cast<char *>(vec.data()), f.size());
     }
 
     QCache<Hash, QPixmap> mCachePixmap;
@@ -106,8 +108,9 @@ GravatarCache *GravatarCache::self()
 
 void GravatarCache::saveGravatarPixmap(const Hash &hash, const QPixmap &pixmap)
 {
-    if (!hash.isValid() || pixmap.isNull())
+    if (!hash.isValid() || pixmap.isNull()) {
         return;
+    }
 
     const QString path = d->mGravatarPath + hash.hexString() + QLatin1String(".png");
     qCDebug(GRAVATAR_LOG) << " path " << path;
@@ -120,16 +123,16 @@ void GravatarCache::saveGravatarPixmap(const Hash &hash, const QPixmap &pixmap)
 void GravatarCache::saveMissingGravatar(const Hash &hash)
 {
     switch (hash.type()) {
-        case Hash::Invalid:
-            break;
-        case Hash::Md5:
-            d->insertMissingHash(d->mMd5Misses, hash.md5());
-            d->saveVector(d->mMd5Misses, QStringLiteral("missing.md5"));
-            break;
-        case Hash::Sha256:
-            d->insertMissingHash(d->mSha256Misses, hash.sha256());
-            d->saveVector(d->mSha256Misses, QStringLiteral("missing.sha256"));
-            break;
+    case Hash::Invalid:
+        break;
+    case Hash::Md5:
+        d->insertMissingHash(d->mMd5Misses, hash.md5());
+        d->saveVector(d->mMd5Misses, QStringLiteral("missing.md5"));
+        break;
+    case Hash::Sha256:
+        d->insertMissingHash(d->mSha256Misses, hash.sha256());
+        d->saveVector(d->mSha256Misses, QStringLiteral("missing.sha256"));
+        break;
     }
 }
 
@@ -137,8 +140,9 @@ QPixmap GravatarCache::loadGravatarPixmap(const Hash &hash, bool &gravatarStored
 {
     gravatarStored = false;
     qCDebug(GRAVATAR_LOG) << " hashStr" << hash.hexString();
-    if (!hash.isValid())
+    if (!hash.isValid()) {
         return QPixmap();
+    }
 
     // in-memory cache
     if (d->mCachePixmap.contains(hash)) {
@@ -161,16 +165,16 @@ QPixmap GravatarCache::loadGravatarPixmap(const Hash &hash, bool &gravatarStored
 
     // missing gravatar cache (ie. known to not exist one)
     switch (hash.type()) {
-        case Hash::Invalid:
-            break;
-        case Hash::Md5:
-            d->loadVector(d->mMd5Misses, QStringLiteral("missing.md5"));
-            gravatarStored = std::binary_search(d->mMd5Misses.begin(), d->mMd5Misses.end(), hash.md5());
-            break;
-        case Hash::Sha256:
-            d->loadVector(d->mSha256Misses, QStringLiteral("missing.sha256"));
-            gravatarStored = std::binary_search(d->mSha256Misses.begin(), d->mSha256Misses.end(), hash.sha256());
-            break;
+    case Hash::Invalid:
+        break;
+    case Hash::Md5:
+        d->loadVector(d->mMd5Misses, QStringLiteral("missing.md5"));
+        gravatarStored = std::binary_search(d->mMd5Misses.begin(), d->mMd5Misses.end(), hash.md5());
+        break;
+    case Hash::Sha256:
+        d->loadVector(d->mSha256Misses, QStringLiteral("missing.sha256"));
+        gravatarStored = std::binary_search(d->mSha256Misses.begin(), d->mSha256Misses.end(), hash.sha256());
+        break;
     }
 
     return QPixmap();
